@@ -9,15 +9,23 @@ class Command(BaseCommand):
 
     def add_arguments(self, parser):
         parser.add_argument(
-            "-m", "--model", help="If you only want to specify one model",
+            "-m",
+            "--model",
+            help="If you only want to specify one model",
+        )
+        parser.add_argument(
+            "-p",
+            "--prefix",
+            help="Prefix for the location of the mapping",
         )
 
     def handle(self, *args, **kwargs):
         data = get_setting("mapping")
-        option_model = kwargs.get("model", None)
+        option_model = kwargs.get("model")
+        location_prefix = kwargs.get("prefix")
 
         if option_model:
-            scan_model(option_model, data[option_model])
+            scan_model(option_model, data[option_model], location_prefix)
         else:
             for model, output in data.items():
-                scan_model(model, output)
+                scan_model(model, output, location_prefix)
